import React, { useState, useRef, useEffect } from "react";
import { useNavigate } from "react-router-dom";
import { Button, Typography, Grid, Tooltip } from "@mui/material";
import { useUndeployInDb } from "../../../api/SwaggerApi";
import { SimpleAccordion } from "@ess-ics/ce-ui-common";
import { ConfirmationDialog } from "../../dialog/ConfirmationDialog";
import { SimpleModal } from "../../common/SimpleModal/SimpleModal";
import Alert from "@mui/material/Alert";
import AccessControl from "../../auth/AccessControl";
import { IocActiveDeployment } from "../../../api/DataTypes";

export default function AdministerUndeployment({ ioc, buttonDisabled }) {
  const navigate = useNavigate();

  function onError(message) {
    setError(message);
  }

  // for the dialog
  const [error, setError] = useState();
  const [adHocDialogOpen, setAdHocDialogOpen] = useState(false);
  const [adHocDialogTitle, setAdHocDialogTitle] = useState();
  const [adHocDialogDescription, setAdHocDialogDescription] = useState();
  const callbackRef = useRef();

  const [response, undeployIOC] = useUndeployInDb(ioc.id, onError);

  // Setting up dialog properties
  const openUndeployModal = () => {
    setAdHocDialogTitle("Administratively 'undeploy' IOC");
    setAdHocDialogDescription(
      <>
        <Typography style={{ display: "inline-block" }}>
          Are you sure want to administer IOC as undeployed &nbsp;
        </Typography>
        <Typography
          style={{ fontFamily: "monospace", display: "inline-block" }}
        >
          {" "}
          {ioc.namingName}?{" "}
        </Typography>
      </>
    );
    callbackRef.current = undeployIoc;
    setAdHocDialogOpen(true);
  };

  // what to do when "undeploying" the IOC
  const undeployIoc = async () => {
    undeployIOC();
  };

  useEffect(() => {
    if (response) {
      navigate(-1);
    }
  }, [response, navigate]);

  const failedDeployment = new IocActiveDeployment(
    ioc.activeDeployment
  ).failedDeployment();

  let disabledButtonTitle = "";
  if (buttonDisabled || ioc.operationInProgress) {
    disabledButtonTitle =
      "There is an ongoing operation, you cannot 'undeploy' the IOC right now";
  } else {
    if (!failedDeployment) {
      disabledButtonTitle =
        "IOC doesn't have failed (un)deployment, you cannot 'undeploy' it";
    }
  }

  return (
    <AccessControl
      allowedRoles={["DeploymentToolAdmin"]}
      renderNoAccess={() => <></>}
    >
      <>
        <SimpleModal
          open={adHocDialogOpen}
          setOpen={setAdHocDialogOpen}
        >
          <ConfirmationDialog
            open={adHocDialogOpen}
            setOpen={setAdHocDialogOpen}
            title={adHocDialogTitle}
            description={adHocDialogDescription}
            callback={callbackRef.current}
          />
        </SimpleModal>

        <SimpleAccordion
          summary="Change deployment status to not deployed (e.g. if IOC has been manually removed)"
          defaultExpanded
        >
          <Grid
            container
            spacing={1}
          >
            {error ? (
              <Grid
                item
                xs={12}
              >
                <Alert severity="error">{error}</Alert>
              </Grid>
            ) : (
              <></>
            )}
            <Grid
              item
              xs={12}
            >
              <Tooltip title={disabledButtonTitle}>
                <span>
                  <Button
                    onClick={openUndeployModal}
                    disabled={
                      buttonDisabled ||
                      ioc.operationInProgress ||
                      !failedDeployment
                    }
                    color="error"
                    variant="contained"
                  >
                    SET DEPLOYMENT STATE TO NOT DEPLOYED
                  </Button>
                </span>
              </Tooltip>
            </Grid>
          </Grid>
        </SimpleAccordion>
      </>
    </AccessControl>
  );
}
