import React from "react";
import { Table } from "@ess-ics/ce-ui-common";
import { Grid } from "@mui/material";
import { EllipsisTextLink, noWrapText } from "../common/Helper";
import { JobTypeIcon } from "./JobIcons";
import { formatDate } from "../common/Helper";

const jobLogColumns = [
  {
    field: "type",
    headerName: "Type",
    headerAlign: "center",
    align: "center",
    maxWidth: 60
  },
  { field: "ioc", headerName: "IOC name", minWidth: 120 },
  { field: "version", headerName: "Revision", minWidth: 120 },
  { field: "host", headerName: "Host", minWidth: 120 },
  { field: "user", headerName: "User", minWidth: 100 },
  {
    field: "start",
    headerName: "Time",
    minWidth: 120,
    sortable: false,
    headerAlign: "right",
    align: "right"
  }
];

const userPageJobLogColumns = [
  ...jobLogColumns.filter((it) => it.field !== "user")
];

function createTableRow(job, colorStyle) {
  return {
    id: job.id,
    type: (
      <Grid
        container
        direction="column"
        justifyContent="center"
        alignItems="center"
      >
        <JobTypeIcon
          type={job.type}
          colorStyle={colorStyle}
        />
      </Grid>
    ),
    ioc: (
      <EllipsisTextLink
        text={job.iocName}
        href={`/iocs/${job.iocId}`}
      />
    ),
    version: (
      <EllipsisTextLink
        text={job.gitReference}
        href={`/jobs/${job?.id}`}
      />
    ),
    host: job.host?.hostName ? (
      <EllipsisTextLink
        text={job.host?.hostName}
        href={`/hosts/${job?.host?.externalHostId}`}
      />
    ) : null,
    user: (
      <EllipsisTextLink
        text={job.createdBy}
        href={`/user/${job.createdBy}`}
      />
    ),
    start: noWrapText(formatDate(job.createdAt))
  };
}

function createTableRowJobLog(job) {
  return createTableRow(job, "black");
}

export function JobTable({
  jobs,
  rowType = "jobLog",
  pagination,
  onPage,
  loading
}) {
  const tableTypeSpecifics = {
    jobLog: [jobLogColumns, createTableRowJobLog],
    userPageJobLog: [userPageJobLogColumns, createTableRowJobLog]
  };

  const [columns, createRow] = tableTypeSpecifics[rowType];

  return (
    <Table
      columns={columns}
      rows={jobs?.map((job) => createRow(job))}
      pagination={pagination}
      onPage={onPage}
      loading={loading}
    />
  );
}
