import React, { useContext, useEffect } from "react";
import { Paper, Skeleton } from "@mui/material";
import { KeyValueTable } from "@ess-ics/ce-ui-common/dist/components/common/KeyValueTable";
import { apiContext } from "../../../api/DeployApi";
import { useAPIMethod } from "@ess-ics/ce-ui-common";

const renderValue = (val) => {
  return val ?? <Skeleton width="3ch" />;
};

export function IOCStatistics() {
  const client = useContext(apiContext);

  // Do not call on render; when one of these finishes then it and the others
  // will be called again on the next render; this causes an infinite loop.
  const { value: iocsRegistered, wrapper: getIocsRegistered } = useAPIMethod({
    fcn: client.apis.Statistics.calculateStatistics,
    call: false
  });
  const { value: iocsDeployed, wrapper: getIocsDeployed } = useAPIMethod({
    fcn: client.apis.Statistics.calculateStatistics,
    call: false
  });
  const { value: iocsReachable, wrapper: getIocsReachable } = useAPIMethod({
    fcn: client.apis.Statistics.calculateStatistics,
    call: false
  });
  const { value: iocsWithoutIssues, wrapper: getIocsWithoutIssues } =
    useAPIMethod({
      fcn: client.apis.Statistics.calculateStatistics,
      call: false
    });

  useEffect(() => {
    getIocsRegistered({ statistics_type: "IOCS_REGISTERED" });
    getIocsDeployed({ statistics_type: "IOCS_DEPLOYED" });
    getIocsReachable({ statistics_type: "IOCS_RUNNING" });
    getIocsWithoutIssues({ statistics_type: "IOCS_RUNNING_WITHOUT_ISSUE" });
  }, [
    getIocsDeployed,
    getIocsReachable,
    getIocsRegistered,
    getIocsWithoutIssues
  ]);

  const iocStats = {
    "Registered IOCs": renderValue(iocsRegistered?.value),
    "Deployed IOCs": renderValue(iocsDeployed?.value),
    "Running IOCs": renderValue(iocsReachable?.value),
    "Issue-free and running IOCs": renderValue(iocsWithoutIssues?.value)
  };

  return (
    <Paper>
      <KeyValueTable
        obj={iocStats}
        keyOptions={{ headerName: "IOC statistics" }}
        valueOptions={{
          headerName: "",
          align: "right"
        }}
        sx={{ border: 0 }}
      />
    </Paper>
  );
}
