import { useCallback, useEffect, useRef } from "react";

export function useInterval(callback, interval, call = false) {
  useEffect(() => {
    if (call) callback(); // call the callback right away
    const id = setInterval(callback, interval);
    return () => clearInterval(id);
  }, [call, callback, interval]);
}

export function useSafePolling(callback, busy, interval, call = true) {
  const busyRef = useRef(busy);
  busyRef.current = busy;

  const poll = useCallback(() => {
    if (!busyRef.current) {
      callback();
    }
  }, [callback, busyRef]);
  useInterval(poll, interval, call);
}
